@@ -262,7 +262,7 @@ status_label_clear (gpointer data)
 static void
 send_button_cb (GtkWidget *widget, NS_ui *ui)
 {
-	char *error;
+	char *f, *error;
 	NstPlugin *p;
 	GtkWidget *w;
 
@@ -303,14 +303,11 @@ send_button_cb (GtkWidget *widget, NS_ui *ui)
 			       p->info->id);
 
 	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(ui->pack_checkbutton))){
-		char *f;
-
 		f = pack_files (ui);
 		if (f != NULL) {
 			GList *packed_file = NULL;
 			packed_file = g_list_append (packed_file, f);
 			if (!p->info->send_files (p, w, packed_file)) {
-				g_free (f);
 				g_list_free (packed_file);
 				return;
 			}
@@ -319,7 +316,6 @@ send_button_cb (GtkWidget *widget, NS_ui *ui)
 			gtk_widget_set_sensitive (ui->dialog, TRUE);
 			return;
 		}
-		g_free (f);
 	} else {
 		if (!p->info->send_files (p, w, file_list)) {
 			g_list_foreach (file_list, (GFunc) g_free, NULL);
@@ -765,7 +761,6 @@ nautilus_sendto_init (void)
 
 		file = g_file_new_for_commandline_arg (filenames[i]);
 		filename = g_file_get_path (file);
-		g_object_unref (file);
 		if (filename == NULL)
 			continue;
 
@@ -802,7 +797,7 @@ int main (int argc, char **argv)
 	textdomain (GETTEXT_PACKAGE);
 
 	g_thread_init (NULL);
-	context = g_option_context_new ("");
+	context = g_option_context_new ("nautilus-sendto");
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	if (g_option_context_parse (context, &argc, &argv, &error) == FALSE) {
